/*
    (C) 1995-99 AROS - The Amiga Research OS
    $Id: queryoverscan.c,v 1.3 2007/10/22 21:48:14 piru Exp $
 
    Desc: Intuition function QueryOverscan()
    Lang: english
*/
#include <graphics/displayinfo.h>
#include <proto/graphics.h>
#include "intuition_intern.h"

/*****************************************************************************
 
    NAME */
#include <proto/intuition.h>

AROS_LH3(LONG, QueryOverscan,

         /*  SYNOPSIS */
         AROS_LHA(ULONG             , displayid, A0),
         AROS_LHA(struct Rectangle *, rect     , A1),
         AROS_LHA(WORD              , oscantype, D0),

         /*  LOCATION */
         struct IntuitionBase *, IntuitionBase, 79, Intuition)

/*  FUNCTION
 
    INPUTS
 
    RESULT
 
    NOTES
 
    EXAMPLE
 
    BUGS
 
    SEE ALSO
 
    INTERNALS
 
    HISTORY
 
*****************************************************************************/
{
	AROS_LIBFUNC_INIT
	AROS_LIBBASE_EXT_DECL(struct IntuitionBase *,IntuitionBase)

	struct DimensionInfo diminfo;
	LONG		 retval = FALSE;

	DEBUG_QUERYOVERSCAN(dprintf("LIB_QueryOverscan: displayid 0x%lx rect 0x%lx oscantype 0x%lx\n",
	                            displayid,
	                            rect,
	                            oscantype));

	DEBUG_QUERYOVERSCAN(dprintf("LIB_QueryOverscan: %ld %ld %ld %ld\n",
	                            rect->MinX,
	                            rect->MinY,
	                            rect->MaxX,
	                            rect->MaxY));
	ASSERT_VALID_PTR(rect);

	if (GetDisplayInfoData(NULL, (UBYTE *)&diminfo, sizeof(diminfo), DTAG_DIMS, displayid) > 0)
	{
		retval = TRUE;

		switch(oscantype)
		{
		default:
			DEBUG_QUERYOVERSCAN(dprintf("LIB_QueryOverscan: OSCAN_????, fall back to OSCAN_TEXT\n"));
		case OSCAN_TEXT:
			DEBUG_QUERYOVERSCAN(dprintf("LIB_QueryOverscan: OSCAN_TEXT\n"));
			memcpy(rect,&diminfo.TxtOScan,sizeof(struct Rectangle));
			break;

		case OSCAN_STANDARD:
			DEBUG_QUERYOVERSCAN(dprintf("LIB_QueryOverscan: OSCAN_STANDARD\n"));
			memcpy(rect,&diminfo.StdOScan,sizeof(struct Rectangle));
			break;

		case OSCAN_MAX:
			DEBUG_QUERYOVERSCAN(dprintf("LIB_QueryOverscan: OSCAN_MAX\n"));
			memcpy(rect,&diminfo.MaxOScan,sizeof(struct Rectangle));
			break;

		case OSCAN_VIDEO:
			DEBUG_QUERYOVERSCAN(dprintf("LIB_QueryOverscan: OSCAN_VIDEO\n"));
			memcpy(rect,&diminfo.VideoOScan,sizeof(struct Rectangle));
			break;

		} /* switch(oscantype) */

	} /* if (GetDisplayInfoData(NULL, &diminfo, sizeof(diminfo), DTAG_DIMS, displayid) > 0) */
	else
	{
		/* Workaround some buggy apps (working ones ignore the
		   values passed here). - Piru */
		rect->MinX = 0;
		rect->MinY = 0;
		rect->MaxX = 640 - 1;
		rect->MaxY = 480 - 1;
	}

	DEBUG_QUERYOVERSCAN(dprintf("LIB_QueryOverscan: retval %ld, %ld %ld %ld %ld\n",
	                            retval,
	                            rect->MinX,
	                            rect->MinY,
	                            rect->MaxX,
	                            rect->MaxY));

	return retval;

	AROS_LIBFUNC_EXIT

} /* QueryOverscan */
